OwnedBufRawParts

Struct OwnedBufRawParts 

pub struct OwnedBufRawParts {
    pub ptr: NonNull<u8>,
    pub cap: usize,
    pub init: usize,
}
The raw parts of an OwnedBuf.

Fields

ptr: NonNull<u8>

Base pointer of the buffer.

cap: usize

The capacity of the buffer. This many bytes starting with ptr and going upward are owned by an OwnedBuf that returns this from .as_raw_parts().

init: usize

The initialization cursor of the buffer. This many bytes starting with ptr and going upward are safe to read (known not to contain traces of previous memory allocations and internal allocator data structures). Must not exceed the capacity.